@@ -3,7 +3,7 @@ package simpleXMLParse;
 # Perl Module: simpleXMLParse
 # Author: Daniel Edward Graham
 # Copyright (c) Daniel Edward Graham 2008-2015
-# Date: 2/17/2015 
+# Date: 4/06/2015 
 # License: LGPL 3.0
 # 
 
@@ -24,7 +24,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 	
 );
 
-$VERSION = '2.9';
+$VERSION = '3.0';
 
 use Carp;
 use strict;
@@ -171,6 +171,7 @@ sub _ParseXML {
     $xml =~ s/\<\!\-\-[^\>]*?\-\-\>//gs;
     $xml =~ s/\<\!ELEMENT[^\>]*?\>//gs;
     $xml =~ s/\<\!ENTITY[^\>]*?\>//gs;
+    $xml =~ s/\<\!ATTLIST[^\>]*?\>//gs;
     $xml =~ s/\<\!DOCTYPE[^\>]*?\>//gs;
     my $rethash = ();
     my @retarr;
@@ -216,7 +217,6 @@ sub _ParseXML {
     my $ixml = $innerxml;
     while ($ixml =~ /^.*?\<${firsttag}(\>|[\s\n]\>|[\s\n][^\>]*[^\/]\>)(.*?)$/s) {
         $ixml = $2;
-        print STDERR "***\n";
         $innerxml .= "</${firsttag}>";
         if ($xmlfragment =~ /^(.*?)\<\/${firsttag}[\s\n]*\>(.*)$/s) {
             my $ix = $1;
@@ -377,7 +377,7 @@ Daniel Graham, E<lt>dgraham@firstteamsoft.com<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2014 by Daniel Edward Graham
+Copyright (C) 2008-2015 by Daniel Edward Graham
 
 LGPL 3.0
 
